/*
 * SQLTable.java
 *
 * Created on 19 de julio de 2002, 13:13
 */

package components;
import javax.swing.table.*;
import javax.swing.*;

/**
 *
 * @author  nestor
 */
public class SQLTable extends JTable {
    SQLTableModel t_model = null;
    
    public SQLTable() {
        t_model = new SQLTableModel(this);
        setModel(t_model);
        setAutoResizeMode(AUTO_RESIZE_OFF);
    }
    
    public void setTableModel(SQLTableModel _model){
        t_model = _model;
    }
    public SQLTableModel getTableModel(){
        return (SQLTableModel) getModel();
    }
    
    public void showColumns(int columns){
        t_model.showColumns(columns);
    }
}
